# Generated by Django 5.0 on 2023-12-21 22:30

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0006_alter_datatheme_code"),
    ]

    operations = [
        migrations.AddField(
            model_name="dataset",
            name="issued",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="dataset",
            name="modified",
            field=models.DateField(blank=True, null=True),
        ),
    ]
