# Generated by Django 5.0 on 2024-01-05 16:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0009_alter_agent_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="dataset",
            name="landing_page",
            field=models.URLField(blank=True),
        ),
    ]
