# Generated by Django 5.0 on 2023-12-21 22:39

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0007_dataset_issued_dataset_modified"),
    ]

    operations = [
        migrations.CreateModel(
            name="DataService",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("endpoint_url", models.URLField()),
                ("description", models.TextField(blank=True)),
                (
                    "catalog",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="dcat.catalog"
                    ),
                ),
                ("format", models.ManyToManyField(blank=True, to="dcat.mediatype")),
                (
                    "licence",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="dcat.licencedocument",
                    ),
                ),
            ],
        ),
    ]
