# Generated by Django 5.0 on 2023-12-21 00:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0004_alter_catalog_themes_alter_dataset_description_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Keyword",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=50)),
                ("slug", models.SlugField()),
            ],
        ),
        migrations.AddField(
            model_name="dataset",
            name="keywords",
            field=models.ManyToManyField(blank=True, to="dcat.keyword"),
        ),
    ]
