# Generated by Django 5.0 on 2024-01-05 16:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0011_alter_distribution_file"),
    ]

    operations = [
        migrations.AddField(
            model_name="distribution",
            name="external_access_url",
            field=models.URLField(blank=True, default=""),
        ),
    ]
