# Generated by Django 5.0 on 2024-01-05 16:33

import dcat.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0010_dataset_landing_page"),
    ]

    operations = [
        migrations.AlterField(
            model_name="distribution",
            name="file",
            field=models.FileField(
                blank=True, upload_to=dcat.models.Distribution._get_storage_path
            ),
        ),
    ]
