# Generated by Django 5.0 on 2024-01-06 20:55

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("dcat", "0012_distribution_external_access_url"),
    ]

    operations = [
        migrations.AlterField(
            model_name="catalog",
            name="licence",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="dcat.licencedocument",
            ),
        ),
    ]
